==> tidy-0.1.0-alpha.jar: META-INF/leiningen/tomthought/tidy/project.clj <==
(defproject tomthought/tidy "0.1.0-alpha"
  :description "Concurrency patterns using Clojure core.async."
  :url "https://github.com/tomthought/tidy"
  :license {:name "Eclipse Public License"
            :url "http://www.eclipse.org/legal/epl-v10.html"}
  :dependencies [[org.clojure/clojure "1.9.0"]
                 [org.clojure/clojurescript "1.10.238"]
                 [org.clojure/core.async "0.4.474"]

                 [com.7theta/utilis "1.1.0"]
                 [com.andrewmcveigh/cljs-time "0.5.2"]
                 [com.taoensso/timbre "4.10.0"]

                 [funcool/beicon "4.1.0"]

                 [clj-time "0.14.2"]]

  :plugins [[lein-cljsbuild "1.1.5"]]

  :min-lein-version "2.5.3"

  :source-paths ["src"]

  :clean-targets ^{:protect false} ["resources/public/js/compiled" "target"]

  :figwheel {:server-port 3449 ;; default
             :open-file-command "emacsclient"
             :nrepl-middleware ["cider.nrepl/cider-middleware"]}

  :profiles
  {:dev
   {:dependencies [[figwheel-sidecar "0.5.15"]
                   [com.cemerick/piggieback "0.2.2"]
                   [org.clojure/tools.nrepl "0.2.13"]
                   [org.clojure/tools.namespace "0.2.11"]
                   [org.clojure/test.check "0.10.0-alpha2"]]
    :repl-options {:nrepl-middleware [cemerick.piggieback/wrap-cljs-repl]}
    :plugins      [[lein-figwheel "0.5.9"]]
    :source-paths ["dev" "src"]
    :figwheel {:http-server-root "public" ;; default and assumes "resources"
               :server-port 3449 ;; default
               :css-dirs ["public/css"]
               :open-file-command "emacsclient"
               :nrepl-middleware ["cider.nrepl/cider-middleware"]}
    }}

  :cljsbuild
  {:builds
   [{:id           "dev"
     :source-paths ["src"]
     :compiler     {:main                 tidy.core
                    :output-to            "resources/public/js/compiled/app.js"
                    :output-dir           "resources/public/js/compiled/out"
                    :asset-path           "js/compiled/out"
                    :source-map-timestamp true
                    }
     :figwheel {:websocket-host "localhost"
                :auto-jump-to-source-on-error true}}

    {:id           "min"
     :source-paths ["src"]
     :compiler     {:main            tidy.core
                    :output-to       "resources/public/js/compiled/app.js"
                    :optimizations   :advanced
                    :closure-defines {goog.DEBUG false}
                    :pretty-print    false}}


    ]}

  :scm {:name "git"
        :url "https://github.com/tomthought/tidy"}

  )

==> tidy-0.3.0-alpha.jar: META-INF/leiningen/tomthought/tidy/project.clj <==
(defproject tomthought/tidy "0.3.0-alpha"
  :description "Reaction graphs in Clojure"
  :url "https://github.com/tomthought/tidy"
  :license {:name "Eclipse Public License"
            :url "http://www.eclipse.org/legal/epl-v10.html"}
  :dependencies [[org.clojure/clojure "1.9.0"]
                 [org.clojure/clojurescript "1.10.238"]
                 [org.clojure/core.async "0.4.474"]

                 [com.7theta/utilis "1.1.0"]
                 [com.andrewmcveigh/cljs-time "0.5.2"]
                 [com.taoensso/timbre "4.10.0"]

                 [funcool/beicon "4.1.0"]

                 [clj-time "0.14.2"]]

  :plugins [[lein-cljsbuild "1.1.5"]]

  :min-lein-version "2.5.3"

  :source-paths ["src"]

  :clean-targets ^{:protect false} ["resources/public/js/compiled" "target"]

  :figwheel {:server-port 3449 ;; default
             :open-file-command "emacsclient"
             :nrepl-middleware ["cider.nrepl/cider-middleware"]}

  :profiles
  {:dev
   {:dependencies [[figwheel-sidecar "0.5.15"]
                   [com.cemerick/piggieback "0.2.2"]
                   [org.clojure/tools.nrepl "0.2.13"]
                   [org.clojure/tools.namespace "0.2.11"]
                   [org.clojure/test.check "0.10.0-alpha2"]]
    :repl-options {:nrepl-middleware [cemerick.piggieback/wrap-cljs-repl]}
    :plugins      [[lein-figwheel "0.5.9"]]
    :source-paths ["dev" "src"]
    :figwheel {:http-server-root "public" ;; default and assumes "resources"
               :server-port 3449 ;; default
               :css-dirs ["public/css"]
               :open-file-command "emacsclient"
               :nrepl-middleware ["cider.nrepl/cider-middleware"]}
    }}

  :cljsbuild
  {:builds
   [{:id           "dev"
     :source-paths ["src"]
     :compiler     {:main                 tidy.core
                    :output-to            "resources/public/js/compiled/app.js"
                    :output-dir           "resources/public/js/compiled/out"
                    :asset-path           "js/compiled/out"
                    :source-map-timestamp true
                    }
     :figwheel {:websocket-host "localhost"
                :auto-jump-to-source-on-error true}}

    {:id           "min"
     :source-paths ["src"]
     :compiler     {:main            tidy.core
                    :output-to       "resources/public/js/compiled/app.js"
                    :optimizations   :advanced
                    :closure-defines {goog.DEBUG false}
                    :pretty-print    false}}


    ]}

  :scm {:name "git"
        :url "https://github.com/tomthought/tidy"}

  )
